@@ -7,7 +7,7 @@ import functools
 import types
 import warnings
 
-__version__ = "2.4.0"
+__version__ = "2.4.1"
 
 # from https://github.com/python/cpython/blob/main/Lib/_collections_abc.py
 # missing from python < 3.6
@@ -235,6 +235,9 @@ class ArgumentParser(argparse.ArgumentParser):
         argparse.ArgumentParser.__init__(self, *args, **kwargs)
         self._config_actions = None
 
+        # to toggle legacy behavior
+        self._ignore_conflict_config_only = False
+
         # initialize config args from options
         self._init_config()
 
@@ -498,6 +501,8 @@ class ArgumentParser(argparse.ArgumentParser):
         existing_dests = [arg for arg in list(args) + list(kwargs) if arg in self._dests_actions]
         if len(existing_dests)>0: raise MagiConfigError("the following dests are already used by regular (not config-only) arguments: "+', '.join(existing_dests))
 
+        # legacy behavior: add_config_only could be called for the same dest multiple times
+        self._ignore_conflict_config_only = True
         for dest in args:
             self.add_config_argument(dest)
         for dest,default in six.iteritems(kwargs):
@@ -505,6 +510,7 @@ class ArgumentParser(argparse.ArgumentParser):
                 self.add_config_argument(dest, required=True)
             else:
                 self.add_config_argument(dest, default=default)
+        self._ignore_conflict_config_only = False
 
     # remove config-only argument
     def remove_config_only(self, arg):
@@ -569,7 +575,7 @@ class ArgumentParser(argparse.ArgumentParser):
 
     def _add_config_only_action(self, action):
         # check for existing dests
-        if action.dest in self._config_only: raise argparse.ArgumentError(action, "conflicting config-only dest: {}".format(action.dest))
+        if action.dest in self._config_only and not self._ignore_conflict_config_only: raise argparse.ArgumentError(action, "conflicting config-only dest: {}".format(action.dest))
         if action.dest in self._dests_actions: raise argparse.ArgumentError(action, "dest {} already specified as regular (not config-only) argument".format(action.dest))
 
         # add to actions list
